%
% converting PCC under bidirectional constraints specified by Ab
%     Ab : face vectors for bidirectional constraints
%     Au : face vectors for unidirectional constraints
%     n : dimension
%
function [ U, E, V ] = PCC_convert_less ( Ab, Au, n )
    [Z,B] = null_and_complement_null(Ab');
    m = size(Z,2); % dim of null space of Ab

    alpha = zeros(m, size(Au,2));
    for k=1:size(Au,2);
        alpha(:,k) = (Au(:,k)'*Z)';
    end
    [ beta, betaE, betaV ] = PCC_convert_full(alpha,m);
    %betaE % this should be empty as alpha provides a proper cone

    U = zeros(n, size(beta,2));
    for k=1:size(beta,2)
        U(:,k) = Z*beta(:,k);
    end
    E = zeros(n, size(betaE,2));
    for k=1:size(betaE,2)
        E(:,k) = Z*betaE(:,k);
    end
    V = zeros(n, size(betaV,2));
    for k=1:size(betaV,2)
        V(:,k) = Z*betaV(:,k);
    end
end
